"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from builtins import (
    int,
)
from google.protobuf.descriptor import (
    Descriptor,
    FileDescriptor,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    Literal,
    final,
)

DESCRIPTOR: FileDescriptor

@final
class Ping(Message):
    DESCRIPTOR: Descriptor

    A_FIELD_NUMBER: int
    B_FIELD_NUMBER: int
    a: int
    b: int
    def __init__(
        self,
        *,
        a: int = ...,
        b: int = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["a", b"a", "b", b"b"]) -> None: ...

@final
class Pong(Message):
    DESCRIPTOR: Descriptor

    C_FIELD_NUMBER: int
    c: int
    def __init__(
        self,
        *,
        c: int = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["c", b"c"]) -> None: ...
