"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from builtins import (
    bool,
    float,
    int,
    str,
)
from collections.abc import (
    Iterable,
)
from google.protobuf.descriptor import (
    Descriptor,
    FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    Literal,
    final,
)

DESCRIPTOR: FileDescriptor

@final
class FlightSearchData(Message):
    DESCRIPTOR: Descriptor

    REG_FIELD_NUMBER: int
    SCHD_FROM_FIELD_NUMBER: int
    SCHD_TO_FIELD_NUMBER: int
    FLIGHT_FIELD_NUMBER: int
    OPERATOR_FIELD_NUMBER: int
    AC_TYPE_FIELD_NUMBER: int
    LAT_FIELD_NUMBER: int
    LON_FIELD_NUMBER: int
    CALLSIGN_FIELD_NUMBER: int
    ID_FIELD_NUMBER: int
    RESTRICTED_FIELD_NUMBER: int
    reg: str
    schd_from: str
    schd_to: str
    flight: str
    operator: str
    ac_type: str
    lat: float
    lon: float
    callsign: str
    id: int
    restricted: bool
    def __init__(
        self,
        *,
        reg: str = ...,
        schd_from: str = ...,
        schd_to: str = ...,
        flight: str = ...,
        operator: str = ...,
        ac_type: str = ...,
        lat: float = ...,
        lon: float = ...,
        callsign: str = ...,
        id: int = ...,
        restricted: bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["ac_type", b"ac_type", "callsign", b"callsign", "flight", b"flight", "id", b"id", "lat", b"lat", "lon", b"lon", "operator", b"operator", "reg", b"reg", "restricted", b"restricted", "schd_from", b"schd_from", "schd_to", b"schd_to"]) -> None: ...

@final
class FetchSearchIndexRequest(Message):
    DESCRIPTOR: Descriptor

    def __init__(
        self,
    ) -> None: ...

@final
class FetchSearchIndexResponse(Message):
    DESCRIPTOR: Descriptor

    FLIGHTS_LIST_FIELD_NUMBER: int
    @property
    def flights_list(self) -> RepeatedCompositeFieldContainer[FlightSearchData]: ...
    def __init__(
        self,
        *,
        flights_list: Iterable[FlightSearchData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["flights_list", b"flights_list"]) -> None: ...
